package DumperDB;

use strict;
use warnings;

my $dbName = 'appldb';
my $dbType = 'Pg';
my $dbh;

sub getDbh {
  unless ( defined $dbh ) {
    $dbh = Db::DbConnect::getDbConnect( $dbType, undef, undef, $dbName );
    unless ( ref($dbh) =~ /HASH/
      && ref( $dbh->{'EXECUTE'} ) =~ /CODE/ )
    {
      die "Unable connect to the database";
    }
  }
  return $dbh;
}

sub executeOneRowQuery {
  my ( $query ) = @_;

  my $wrapDbh = getDbh();

  my $rowNumber = $wrapDbh->{'EXECUTE'}->($query);

  if ( $rowNumber && $rowNumber != 1 ) {
    $wrapDbh->{'FINISH'}->();
    die(
      "Expected to have exactly one row in a query result.\n" . 
      "Rows number: $rowNumber\n" . 
      "Query: $query"
    );
  }

  my $ptrHash = $wrapDbh->{'FETCHHASH'}->();
  $wrapDbh->{'FINISH'}->();
  return $ptrHash;
}

sub executeOneValueQuery {
  my ( $query, $column ) = @_;
  my $resultRow = executeOneRowQuery($query);

  my $columnNumber = keys %{$resultRow};

  if ( $columnNumber != 1 ) {
    die(
      "Expected to have exactly one column in a query result.\n" . 
      "Columns number: $columnNumber\n" .
      "Query: $query"
    );
  }

  my ($key, $value) = each %{$resultRow};

  return $value;
}

1;
